<?php
/**
 * Menu callback - admin form for service account credentials settings.
 */
function google_analytics_light_reports_api_admin_form($form, &$form_state) {
  $form = array();
  $form['guide_text'] = array(
    '#type' => 'markup',
    '#markup' => '<h2 id="enable">Step 1: Enable the Analytics API</h2>
	<p>To get started using Google Analytics API, you need to first <a href="https://console.developers.google.com/start/api?id=analytics&credential=client_key">use  the setup tool</a>, which guides you through creating a project in the  Google API Console, enabling the API, and creating credentials.</p>
	<h3 id="clientId">Create a client ID</h3>
	<ol>
	  <li>Open the <a href="https://console.developers.google.com/iam-admin/serviceaccounts"><strong>Service accounts</strong> page</a>. If prompted,  select a project.</li>
	  <li>Click <strong>Create service account</strong>.</li>
	  <li> In the <strong>Create service account</strong> window, type a name for the service      account, and select <strong>Furnish a new private key</strong>. If you want to <a href="https://developers.google.com/identity/protocols/OAuth2ServiceAccount#delegatingauthority">grant      G Suite domain-wide authority</a> to the service account, also select <strong>Enable G Suite Domain-wide Delegation</strong>.            Then click <strong>Save</strong>.</li>
	</ol>
	<p>Your new public/private key pair is generated and downloaded to your machine;  it serves as the only copy of this key. You are responsible for storing it  securely.</p>
	<h3 id="add-user">Step 2: Add service account to Google Analytics account</h3>
	<p>The newly created service account will have an email address,    &lt;projectId&gt;-&lt;uniqueId&gt;@developer.gserviceaccount.com;    Use this email address to <a href="https://support.google.com/analytics/answer/1009702">add    a user</a> to the Google analytics account you want to access via the API.    For this tutorial only <a href="https://support.google.com/analytics/answer/2884495">Read    &amp; Analyze</a> permissions are needed. </p>
	<p> For more detail <a href="https://developers.google.com/analytics/devguides/reporting/core/v3/quickstart/service-php">click here</a></p>
	<p><strong>Step 3: Upload the previously downloaded service-account-credentials.json below.</strong></p>
	<p>&nbsp;</p>'
   );
   $form['google_analytics_light_json_file'] = array(
    '#type' => 'managed_file',
    '#title' => t('Service account credentials'),
    '#default_value' => variable_get('google_analytics_light_json_file', ''),
    '#upload_location' => 'public://google_analytics_light_reports',
    '#description' => t('Upload a file, allowed extensions: json.Use the developers console and download your service account credentials in JSON format.'),
    '#upload_validators' => array(
      'file_validate_extensions' => array('json'),
    )
  );
  $fid = variable_get('google_analytics_light_json_file', ''); 
  $file_obj = file_load($fid);
  $KEY_FILE_LOCATION = drupal_realpath($file_obj->uri);
  if(!empty($KEY_FILE_LOCATION)){
    $options = array();
    $library_exist = google_analytics_report_library_exists();
    if($library_exist){
      $analytics = google_analytics_report_initialize_analytics();
      $accounts = $analytics->management_accounts->listManagementAccounts();
      if (count($accounts->getItems()) > 0) {
        foreach($accounts->getItems() as $account){
	  $options[$account->getId()] = $account->getName();
	}
      }
      $form['g_analytics_report_account'] = array(
        '#type' => 'select',
        '#title' => t('Select Account'),
        "#empty_option" => t('- Select -'),
        '#options' => $options,
        '#default_value' => isset($form_state['values']['g_analytics_report_account']) ? $form_state['values']['g_analytics_report_account'] : variable_get('g_analytics_report_account', ''),
        '#ajax' => array(
          'wrapper' => 'matching-property-wrapper',
          'callback' => 'g_analytics_report_account_list_ajax_callback',
          'event' => 'change',
          'effect' => 'fade',
        ),
      );
      $selected_property = array();
      $account_id = isset($form_state['values']['g_analytics_report_account']) ? $form_state['values']['g_analytics_report_account'] : variable_get('g_analytics_report_account', '');
      if(!empty($account_id)){
        // Get the list of properties for the authorized user.
        $properties = $analytics->management_webproperties->listManagementWebproperties($account_id);
        if (count($properties->getItems()) > 0) {
          foreach($properties->getItems() as $pr_items){
	    $selected_property[$pr_items->getId()] = $pr_items->getName();
	  }
        }
      }
      $form['g_analytics_report_property'] = array(
        '#type' => 'select',
        '#empty_option' => t('- Select -'),
        '#title' => t('Select Property'),
        '#options' => $selected_property,
        '#prefix' => '<div id="matching-property-wrapper">',
        '#suffix' => '</div>',
        '#ajax' => array(
          'wrapper' => 'matching-view-wrapper',
          'callback' => 'g_analytics_report_view_list_ajax_callback',
          'event' => 'change',
          'effect' => 'fade',
        ),
        '#default_value' => isset($form_state['values']['g_analytics_report_property']) ? $form_state['values']['g_analytics_report_property'] : variable_get('g_analytics_report_property', ''),
      );
      $selected_view = array();
      $property_id = isset($form_state['values']['g_analytics_report_property']) ? $form_state['values']['g_analytics_report_property'] : variable_get('g_analytics_report_property', '');
      if(!empty($account_id) && !empty($property_id )){
        // Get the list of views (profiles) for the authorized user.
        $profiles = $analytics->management_profiles->listManagementProfiles($account_id, $property_id);
        if (count($profiles->getItems()) > 0) {
          foreach($profiles->getItems() as $profile){
	    $selected_view[$profile->getId()] = $profile->getName();
	  }
        }
      }
      $form['g_analytics_report_view'] = array(
        '#type' => 'select',
        '#empty_option' => t('- Select -'),
        '#title' => t('Select view'),
        '#options' => $selected_view,
        '#prefix' => '<div id="matching-view-wrapper">',
        '#suffix' => '</div>',
        '#default_value' => isset($form_state['values']['g_analytics_report_view']) ? $form_state['values']['g_analytics_report_view'] : variable_get('g_analytics_report_view', ''),
      );
    }
  }
  // Set a submit handler manually because the default submit handler
  // gets overridden by the system_settings_form() submit handler.
  $form['#submit'][] = 'google_analytics_light_reports_api_admin_form_submit';

  return system_settings_form($form);
}

/**
 * Submit handler for the google_analytics_light_reports_api_admin_form.
 */
function google_analytics_light_reports_api_admin_form_submit($form, &$form_state) {
  // file exists
  $fid = $form_state['values']['google_analytics_light_json_file'];
  $file = file_load($fid);
  if ($file->status==0) {
    $file->status = FILE_STATUS_PERMANENT;
    file_save($file);
    // When a module is managing a file, it must manage the usage count.
    // Here we increment the usage count with file_usage_add().
    file_usage_add($file, 'google_analytics_light_reports', 'service-account-credentials-file', 1);
  }
}

/**
 * Implement g_analytics_report_account_list_ajax_callback().
 */
function g_analytics_report_account_list_ajax_callback($form, &$form_state){
  return $form['g_analytics_report_property'];
}

/**
 * Implement g_analytics_report_view_list_ajax_callback().
 */
function g_analytics_report_view_list_ajax_callback($form, &$form_state){
  return $form['g_analytics_report_view'];
}
