<?php
/**
 * @file
 * Provides the Google Analytics Reports in Block
 */

/**
 * Define google analytics report count content.
 *
 * Function to call  google analytics report API to show User,Seession, Bounce Rate 
 * and Pageviews.
 */
function google_analytics_report_count_content() {
  $library_exist = google_analytics_report_library_exists();
  if($library_exist){
    $selected_date = variable_get('g_analytics_report_count_days', '7daysAgo');
    $analytics = google_analytics_report_initialize_analytics();
    $profileId = google_analytics_report_get_profile_id($analytics);
    $data = array();

    if(!empty($profileId)){
    $results = $analytics->data_ga->get('ga:' . $profileId,
          $selected_date,
          'today',
          'ga:users,ga:sessions,ga:bounceRate,ga:pageviews',
          array(
            //'dimensions'  => 'ga:day',
            //'sort'        => '-ga:day',
            //'max-results' => 10
          ) 
        );
    $rows = $results->getRows();
    foreach( $rows as $row ) {
      $data = array(
        'User'   => $row[0],
        'Seession'  => $row[1],
        'Bounce Rate'  => number_format((float)$row[2], 2, '.', ''),
        'Pageviews' => $row[3]
      );
    }
    $output = '';
    $output .= '<table width="100%">';      
    $output .= '<tr>';  
  
    foreach($data as $key => $value ){
      $output .= '<td><div class="total_visit"><h3 class="users_total_title">'. $key.'</h3><div class="total_count">'. $value.'</div></div></td>';
    }
    $output .= '</tr>';
    $output .= '</table>';
    return array(
    'pageview_count' => array(
      '#markup' => $output,
      '#prefix' => '<div class="pageview_count">',
      '#suffix' => '</div>',
    ),
      );
    }
  }
}

/**
 * Define google analytics report list for PageViews content.
 *
 * Function to call  google analytics report API to show list of 
 * Pageviews.
 */
function google_analytics_report_page_views_content() {
  $library_exist = google_analytics_report_library_exists();
  if($library_exist){
    $selected_date = variable_get('g_analytics_report_page_views_days', '7daysAgo');
    $analytics = google_analytics_report_initialize_analytics();
    $profileId = google_analytics_report_get_profile_id($analytics);
    $data = array();

    if(!empty($profileId)){
      $row_data = array();
      $results = $analytics->data_ga->get('ga:' . $profileId,
          $selected_date,
          'today',
          'ga:pageviews',
          array(
            'dimensions'  => 'ga:pagePath,ga:pageTitle',
              'filters' => 'ga:pagePath!@login;ga:pagePath!@dashboard',
            //'sort'        => '-ga:day',
            //'max-results' => 10
          ) 
        );
        $rows = $results->getRows();
        foreach( $rows as $row ) {
          $row_data[] = array( $row[0],$row[1], $row[2]);
        }
  
      $header = array(array('data' => t('Page Path')),array('data' => t('Page Title')),array('data' => t('Pageviews')));
      $output = theme('table', array('header' => $header, 'rows' => $row_data));
      return array(
	'pageview_list' => array(
	  '#markup' => $output,
	  '#prefix' => '<div class="pageview_list">',
	  '#suffix' => '</div>',
	),
      );
    }
  }
}

/**
 * Define google analytics report list for Top Browser content.
 *
 * Function to call  google analytics report API to Top Browser 
 * Pie Chart.
 */
function google_analytics_top_browser_pie_chart_content() {
  $library_exist = google_analytics_report_library_exists();
  if($library_exist){
    $output = '';
    $output .= '<h3>Top Browsers (by pageview)</h3>';
    $output .= '<div id="top_browser_pie_chart"></div>';
    return array(
      'top_browser' => array(
        '#markup' => $output,
	'#prefix' => '<div class="top_browser_content">',
	'#suffix' => '</div>',
        '#attached' => array(
          'css' => array(
            drupal_get_path('module', 'google_analytics_light_report') . '/css/google_analytics_report_light.css',
          ),
          'js' => array(
            drupal_get_path('module', 'google_analytics_light_report') . '/js/amcharts.js',
            drupal_get_path('module', 'google_analytics_light_report') . '/js/dataloader.min.js',
            drupal_get_path('module', 'google_analytics_light_report') . '/js/light.js',
            drupal_get_path('module', 'google_analytics_light_report') . '/js/pie.js',
            drupal_get_path('module', 'google_analytics_light_report') . '/js/google_analytics_report_light_pie.js',
          ),
        ),
      ),
    );
  }
}
